@@ -94,6 +94,15 @@ after cmd_stop => sub {
         "implemented $branch $tags" );
 };
 
+sub safe_branch_name {
+    my ($self, $name ) = @_;
+    $name =~ s/\W/_/g;
+    $name =~ s/_+/_/g;
+    $name =~ s/^_//;
+    $name =~ s/_$//;
+    return $name
+}
+
 no Moose::Role;
 1;
 
@@ -107,7 +116,7 @@ App::TimeTracker::Command::Git - App::TimeTracker Git plugin
 
 =head1 VERSION
 
-version 2.019
+version 2.020
 
 =head1 DESCRIPTION
 
