@@ -43,11 +43,11 @@ sub pretty_date {
     }
     else {
         my $now = now();
-        my $yeseterday = now()->subtract( days => 1 );
+        my $yesterday = now()->subtract( days => 1 );
         if ( $date->dmy eq $now->dmy ) {
             return $date->hms(':');
         }
-        elsif ( $date->dmy eq $yeseterday->dmy ) {
+        elsif ( $date->dmy eq $yesterday->dmy ) {
             return 'yesterday ' . $date->hms(':');
         }
         else {
@@ -73,7 +73,7 @@ App::TimeTracker::Utils - Utility Methods/Functions for App::TimeTracker
 
 =head1 VERSION
 
-version 2.019
+version 2.020
 
 =head1 AUTHOR
 
